@@ -45,7 +45,7 @@ list_fun (mu_folder_t folder, struct mu_list_response *resp, void *data)
   name = resp->name + refinfo->dirlen;
 
   /* There can be only one INBOX */
-  if (refinfo->reflen == 0 && strcmp (name, "INBOX") == 0)
+  if (refinfo->reflen == 0 &&  mu_c_strcasecmp (name, "INBOX") == 0)
     return 0;
 
   /* Ignore mailboxes that contain delimiter as part of their name */
@@ -317,6 +317,6 @@ imap4d_list (struct imap4d_session *session,
   free (cwd);
   free (ref);
   
-  return io_completion_response (command, status, resp_text[status]);
+  return io_completion_response (command, status, "%s", resp_text[status]);
 }
 
