@@ -1,5 +1,5 @@
 /* cfg.h -- general-purpose configuration file parser 
-   Copyright (C) 2007-2012, 2014-2016 Free Software Foundation, Inc.
+   Copyright (C) 2007-2012, 2014-2017 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -23,6 +23,7 @@
 #include <mailutils/debug.h>
 #include <mailutils/opool.h>
 #include <mailutils/util.h>
+#include <mailutils/locus.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
@@ -31,7 +32,6 @@
 extern "C" {
 #endif  
 
-typedef enum mu_cfg_node_type mu_cfg_node_type_t;
 typedef struct mu_cfg_node mu_cfg_node_t;
 typedef struct mu_cfg_tree mu_cfg_tree_t;
 
@@ -65,7 +65,7 @@ enum mu_cfg_node_type
 
 struct mu_cfg_node
 {
-  struct mu_locus locus;
+  struct mu_locus_range locus;
   enum mu_cfg_node_type type;
   char *tag;
   mu_config_value_t *label;
@@ -120,8 +120,6 @@ int mu_cfg_tree_union (mu_cfg_tree_t **pa, mu_cfg_tree_t **pb);
 int mu_cfg_tree_postprocess (mu_cfg_tree_t *tree,
 			     struct mu_cfg_parse_hints *hints);
 
-extern struct mu_locus mu_cfg_locus;
-
 mu_opool_t mu_cfg_lexer_pool (void);
 
 #define MU_CFG_ITER_OK   0
@@ -181,13 +179,16 @@ typedef int (*mu_cfg_section_fp) (enum mu_cfg_section_stage stage,
 
 struct mu_cfg_section
 {
-  const char *ident;
-  char *label;
-  mu_cfg_section_fp parser;
-  void *target;
-  size_t offset;
+  const char *ident;              /* Section identifier */  
+  char *label;                    /* Label description */
+  mu_cfg_section_fp parser;       /* Parser function */
+  void *data;                     /* Data pointer */
+  size_t offset;                  /* Offset within target (see below) */
   mu_list_t /* of mu_cfg_cont */ children;
-  char *docstring;
+  char *docstring;                /* Documentation string */
+  void *target;                   /* Actual pointer to the data. It is
+				     recomputed each time the section is
+				     reduced. */
 };
 
 enum mu_cfg_cont_type
@@ -283,7 +284,7 @@ int mu_cfg_parse_file (mu_cfg_tree_t **return_tree, const char *file,
 int mu_cfg_tree_create (struct mu_cfg_tree **ptree);
 mu_cfg_node_t *mu_cfg_tree_create_node (struct mu_cfg_tree *tree,
 					enum mu_cfg_node_type type,
-					const struct mu_locus *loc,
+					const struct mu_locus_range *loc,
 					const char *tag,
 					const char *label,
 					mu_list_t nodelist);
