@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2002, 2005-2012, 2014-2016 Free Software
+   Copyright (C) 1999-2002, 2005-2012, 2014-2017 Free Software
    Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
@@ -23,6 +23,7 @@
 #include <stdarg.h>
 #include <mailutils/mailutils.h>
 #include <mailutils/cli.h>
+#include <mailutils/locus.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -87,6 +88,7 @@ typedef struct
 {
   mu_sieve_data_type type;
   char *tag;
+  struct mu_locus_range locus;
   union mu_sieve_value_storage v;
 } mu_sieve_value_t;
 
@@ -162,7 +164,9 @@ void mu_sieve_reclaim_default (void *p);
 void mu_sieve_reclaim_value (void *p);
   
 size_t mu_sieve_value_create (mu_sieve_machine_t mach,
-			      mu_sieve_data_type type, void *data);
+			      mu_sieve_data_type type,
+			      struct mu_locus_range const *locus,
+			      void *data);
 
 /* Symbol space functions */
 mu_sieve_registry_t *mu_sieve_registry_add (mu_sieve_machine_t mach,
@@ -287,7 +291,7 @@ int mu_sieve_set_dry_run (mu_sieve_machine_t mach, int val);
 void mu_sieve_get_argc (mu_sieve_machine_t mach, size_t *args, size_t *tags);
 
 mu_mailer_t mu_sieve_get_mailer (mu_sieve_machine_t mach);
-int mu_sieve_get_locus (mu_sieve_machine_t mach, struct mu_locus *);
+int mu_sieve_get_locus (mu_sieve_machine_t mach, struct mu_locus_range *);
 char *mu_sieve_get_daemon_email (mu_sieve_machine_t mach);
 const char *mu_sieve_get_identifier (mu_sieve_machine_t mach);
 
@@ -322,9 +326,13 @@ const char *mu_sieve_type_str (mu_sieve_data_type type);
 /* Principal entry points */
 
 int mu_sieve_compile (mu_sieve_machine_t mach, const char *name);
+int mu_sieve_compile_text (mu_sieve_machine_t mach,
+			   const char *buf, size_t bufsize,
+			   struct mu_locus_point const *pt);
 int mu_sieve_compile_buffer (mu_sieve_machine_t mach,
 			     const char *buf, int bufsize,
-			     const char *fname, int line);
+			     const char *fname, int line)
+  MU_DEPRECATED;
 int mu_sieve_mailbox (mu_sieve_machine_t mach, mu_mailbox_t mbox);
 int mu_sieve_message (mu_sieve_machine_t mach, mu_message_t message);
 int mu_sieve_disass (mu_sieve_machine_t mach);
