@@ -1,5 +1,5 @@
 /* cli.c -- Command line interface for GNU Mailutils
-   Copyright (C) 2016 Free Software Foundation, Inc.
+   Copyright (C) 2016-2017 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -33,6 +33,7 @@
 #include <mailutils/io.h>
 #include <mailutils/syslog.h>
 #include <mailutils/mu_auth.h>
+#include <mailutils/gitinfo.h>
 
 #define MU_LEGACY_CONFIG_FILE SYSCONFDIR "/mailutils.rc"
 
@@ -54,15 +55,16 @@ const char mu_version_copyright[] =
   /* Do *not* mark this string for translation.  %s is a copyright
      symbol suitable for this locale, and %d is the copyright
      year.  */
-  "Copyright %s 2007-2016 Free Software Foundation, inc.";
+  "Copyright %s 2007-2017 Free Software Foundation, inc.";
 
 void
 mu_version_hook (struct mu_parseopt *po, mu_stream_t stream)
 {
-#ifdef GIT_DESCRIBE
-  mu_stream_printf (stream, "%s (%s) %s [%s]\n",
+#if MU_GIT_COMMIT_DISTANCE > 0  
+  mu_stream_printf (stream, "%s (%s) %s-%d [%s]\n",
 		    mu_program_name, PACKAGE_NAME, PACKAGE_VERSION,
-		    GIT_DESCRIBE);
+		    MU_GIT_COMMIT_DISTANCE,
+		    MU_GIT_DESCRIBE_STRING);
 #else
   mu_stream_printf (stream, "%s (%s) %s\n", mu_program_name,
 		    PACKAGE_NAME, PACKAGE_VERSION);
@@ -160,7 +162,7 @@ config_verbose (struct mu_parseopt *po, struct mu_option *opt,
 
 static void
 config_lint (struct mu_parseopt *po, struct mu_option *opt,
-		char const *arg)
+	     char const *arg)
 {
   struct app_data *dp = po->po_data;
   dp->lint = 1;
@@ -183,11 +185,27 @@ param_set (struct mu_parseopt *po, struct mu_option *opt, char const *arg)
   mu_cfg_tree_add_node (dp->append_tree, node);
 }
 
+static void
+hangproc (struct mu_parseopt *po, struct mu_option *opt, char const *arg)
+{
+  int n;
+  if (mu_str_to_c (arg, mu_c_int, &n, NULL))
+    {
+      mu_parseopt_error (po, _("%s: bad number"), arg);
+      exit (po->po_exit_error);
+    }
+  mu_wd (n);
+}
+
 struct mu_option mu_common_options[] = {
   /*  MU_OPTION_GROUP(N_("Common options")),*/
-  { "program-name",   0,  N_("NAME"),  MU_OPTION_IMMEDIATE|MU_OPTION_HIDDEN,
+  { "program-name",   0,  N_("NAME"),    MU_OPTION_IMMEDIATE|MU_OPTION_HIDDEN,
     N_("set program name"),
     mu_c_string, NULL, change_progname },
+  { "HANG",           0,  N_("SECONDS"),
+    MU_OPTION_IMMEDIATE|MU_OPTION_ARG_OPTIONAL|MU_OPTION_HIDDEN,
+    N_("wait this number of seconds before startup"),
+    mu_c_string, NULL, hangproc, "3600" },
   MU_OPTION_END
 };
 
@@ -465,6 +483,7 @@ run_commit (void *item, void *data)
     | MU_PARSEOPT_BUG_ADDRESS				\
     | MU_PARSEOPT_EXTRA_INFO				\
     | MU_PARSEOPT_VERSION_HOOK				\
+    | MU_PARSEOPT_PROG_NAME   				\
     | MU_PARSEOPT_NEGATION)
 
 void
@@ -502,8 +521,13 @@ mu_cli_ext (int argc, char **argv,
   /* Set program name */
   if (!(hints.flags & MU_CFHINT_PROGRAM))
     {
-      mu_set_program_name (argv[0]);
-      hints.program = (char*) mu_program_name;
+      if (pohint->po_flags & MU_PARSEOPT_PROG_NAME)
+	hints.program = (char *) pohint->po_prog_name;
+      else
+	{
+	  mu_set_program_name (argv[0]);
+	  hints.program = (char*) mu_program_name;
+	}
       hints.flags |= MU_CFHINT_PROGRAM;
     }
 
@@ -592,7 +616,9 @@ mu_cli_ext (int argc, char **argv,
     po.po_version_hook = pohint->po_version_hook;
   if (flags & MU_PARSEOPT_NEGATION)
     po.po_negation = pohint->po_negation;
-
+  if (flags & MU_PARSEOPT_PROG_NAME)
+    po.po_prog_name = pohint->po_prog_name;
+      
   appd.setup = setup;
   appd.hints = &hints;
   appd.append_tree = NULL;
@@ -694,6 +720,9 @@ mu_cli (int argc, char **argv, struct mu_cli_setup *setup, char **capa,
   pohint.po_version_hook = mu_version_hook;
   pohint.po_flags |= MU_PARSEOPT_VERSION_HOOK;
 
+  pohint.po_negation = "no-";
+  pohint.po_flags |= MU_PARSEOPT_NEGATION;
+  
   cfhint.site_file = mu_site_config_file ();
   cfhint.flags = MU_CFHINT_SITE_FILE | MU_CFHINT_PER_USER_FILE;
   
