@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2011-2012, 2014-2016 Free Software Foundation, Inc.
+   Copyright (C) 2011-2012, 2014-2017 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -875,10 +875,10 @@ _imap_message_unseen (mu_mailbox_t mbox, size_t *pn)
       rc = mu_msgset_get_list (msgset, &list);
       if (rc == 0)
 	{
-	  struct mu_msgrange r;
+	  struct mu_msgrange *r;
 	  rc = mu_list_head (list, (void **) &r);
 	  if (rc == 0)
-	    *pn = r.msg_beg;
+	    *pn = r->msg_beg;
 	}
       mu_msgset_free (msgset);
       return rc;
@@ -1119,9 +1119,11 @@ sum_lines (void *item, void *data)
   struct mu_bodystructure *bs = item;
   size_t *pn = data;
   size_t n;
-
-  if (_compute_lines (bs, &n))
-    return 1;
+  int rc;
+  
+  rc = _compute_lines (bs, &n);
+  if (rc)
+    return rc;
   *pn += n;
   return 0;
 }
@@ -1146,7 +1148,7 @@ _compute_lines (struct mu_bodystructure *bs, size_t *pcount)
       *pcount = 0;
       return mu_list_foreach (bs->v.multipart.body_parts, sum_lines, pcount);
     }
-  return 1;
+  return MU_ERR_USER0;
 }
 
 static int
