@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001-2003, 2005, 2007, 2009-2012, 2014-2016 Free
+   Copyright (C) 1999, 2001-2003, 2005, 2007, 2009-2012, 2014-2017 Free
    Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
@@ -40,7 +40,7 @@ append_to_mailbox (char const *filename, msgset_t *msglist, int mark,
   size_t size;
   mu_message_t msg;
   
-  if ((status = mu_mailbox_create_default (&mbx, filename)) != 0)
+  if ((status = mu_mailbox_create (&mbx, filename)) != 0)
     {
       mu_error (_("Cannot create mailbox %s: %s"), filename, 
                    mu_strerror (status));
@@ -96,7 +96,7 @@ append_to_file (char const *filename, msgset_t *msglist, int mark,
   size_t lines;
   mu_message_t msg;
   mu_locker_t locker;
-  
+
   status = mu_file_stream_create (&ostr, filename,
 				  MU_STREAM_CREAT|MU_STREAM_APPEND);
   if (status)
